==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/it.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Promemoria file",
    "Reminder for {name}" : "Promemoria per {name}",
    "View file" : "Visualizza file",
    "View folder" : "Visualizza cartella",
    "Files reminder" : "Files reminder",
    "Set file reminders" : "Imposta promemoria per i file",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**I\n\nImposta promemoria file.\n\nNota: per usare l'app `Promemoria file`, assicurati che l'app `Notifiche` sia installata e abilitata. L'app `Notifiche` fornisce le API necessarie per il corretto funzionamento dell'app `File reminders`.",
    "Set reminder for \"{fileName}\"" : "Imposta promemoria per \"{fileName}\"",
    "Set reminder at custom date & time" : "Imposta promemoria per data personalizzata & ora",
    "Clear reminder" : "Elimina promemoria",
    "Please choose a valid date & time" : "Si prega di scegliere una data valida & ora",
    "Reminder set for \"{fileName}\"" : "Promemoria impostato per \"{fileName}\"",
    "Failed to set reminder" : "Impossibile impostare il promemoria",
    "Reminder cleared for \"{fileName}\"" : "Promemoria cancellato per \"{fileName}\"",
    "Failed to clear reminder" : "Impossibile cancellare il promemoria",
    "We will remind you of this file" : "Ti ricorderemo questo file",
    "Cancel" : "Annulla",
    "Set reminder" : "Imposta promemoria",
    "Reminder set" : "Promemoria impostato",
    "Set custom reminder" : "Imposta promemoria personalizzato",
    "Later today" : "Più tardi oggi",
    "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
    "Tomorrow" : "Domani",
    "Set reminder for tomorrow" : "Imposta promemoria per domani",
    "This weekend" : "Questo fine settimana",
    "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
    "Next week" : "Settimana successiva",
    "Set reminder for next week" : "Imposta promemoria per la prossima settimana"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_reminders/l10n/it.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Promemoria file",
    "Reminder for {name}" : "Promemoria per {name}",
    "View file" : "Visualizza file",
    "View folder" : "Visualizza cartella",
    "Files reminder" : "Files reminder",
    "The \"files_reminders\" app can work properly." : "L'app \"files_reminders\" può funzionare correttamente.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "L'app \"files_reminders\" necessita dell'app di notifica per funzionare correttamente. È necessario abilitare le notifiche o disabilitare files_reminder.",
    "Set file reminders" : "Imposta promemoria per i file",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 File reminders**I\n\nImposta promemoria file.\n\nNota: per usare l'app `Promemoria file`, assicurati che l'app `Notifiche` sia installata e abilitata. L'app `Notifiche` fornisce le API necessarie per il corretto funzionamento dell'app `File reminders`.",
    "Please choose a valid date & time" : "Si prega di scegliere una data valida & ora",
    "Reminder set for \"{fileName}\"" : "Promemoria impostato per \"{fileName}\"",
    "Failed to set reminder" : "Impossibile impostare il promemoria",
    "Reminder cleared for \"{fileName}\"" : "Promemoria cancellato per \"{fileName}\"",
    "Failed to clear reminder" : "Impossibile cancellare il promemoria",
    "Reminder at custom date & time" : "Promemoria a data e ora personalizzate",
    "We will remind you of this file" : "Ti ricorderemo questo file",
    "Cancel" : "Annulla",
    "Clear reminder" : "Elimina promemoria",
    "Set reminder" : "Imposta promemoria",
    "Reminder set" : "Promemoria impostato",
    "Custom reminder" : "Promemoria personalizzato",
    "Later today" : "Più tardi oggi",
    "Set reminder for later today" : "Imposta promemoria per più tardi oggi",
    "Tomorrow" : "Domani",
    "Set reminder for tomorrow" : "Imposta promemoria per domani",
    "This weekend" : "Questo fine settimana",
    "Set reminder for this weekend" : "Imposta promemoria per questo fine settimana",
    "Next week" : "Settimana successiva",
    "Set reminder for next week" : "Imposta promemoria per la prossima settimana",
    "This files_reminder can work properly." : "Questo file_promemoria può funzionare correttamente.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "L'app files_reminder necessita dell'app notifiche per funzionare correttamente. È necessario abilitare le notifiche o disabilitare files_reminder.",
    "Set reminder for \"{fileName}\"" : "Imposta promemoria per \"{fileName}\"",
    "Set reminder at custom date & time" : "Imposta promemoria per data personalizzata & ora",
    "Set custom reminder" : "Imposta promemoria personalizzato"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
